import QtQuick 2.6
import Sailfish.Silica 1.0
import QtWebSockets 1.0
import "../assets"

Page {
    WebSocket {
        id: socket
        url: "wss://echo.websocket.org"
        active: true
        onTextMessageReceived: {
            chatView.postIncomingText(message, qsTr("Server"))
            chatView.scrollToBottom();
        }
        onStatusChanged: {
            if (socket.status === WebSocket.Error) {
                console.log("Error: %1".arg(socket.errorString));
            } else if (socket.status === WebSocket.Open) {
                chatView.postInfo(qsTr("Socket opened"));
            } else if (socket.status === WebSocket.Closed) {
                chatView.postInfo(qsTr("Socket closed"));
            }
            chatView.scrollToBottom();
        }
    }
    SilicaFlickable {
        anchors.fill: parent

        Column {
            width: parent.width
            height: parent.height

            ChatView {
                id: chatView
                width: parent.width
                height: parent.height - inputArea.height
                clip: true
                header: PageHeader { title: qsTr("WebSockets Client") }
            }
            Rectangle {
                id: inputArea
                width: parent.width
                height: childrenRect.height
                color: Theme.rgba(Theme.highlightBackgroundColor, Theme.highlightBackgroundOpacity)

                TextField {
                    width: parent.width
                    enabled: socket.status === WebSocket.Open
                    placeholderText: qsTr("Input message")
                    label: qsTr("Message")
                    EnterKey.enabled: text.length > 0
                    EnterKey.iconSource: "image://theme/icon-m-sms"
                    EnterKey.onClicked: {
                        chatView.postOutgoingText(text, qsTr("Me"));
                        chatView.scrollToBottom();
                        socket.sendTextMessage(text);
                        text = "";
                    }
                }
            }
        }
        PushUpMenu {
            MenuItem {
                text: qsTr("Send image")
                onClicked: {
                    var imagePicker =
                        pageStack.push("Sailfish.Pickers.ImagePickerPage");
                    imagePicker.selectedContentChanged.connect(function () {
                        // ToDo: post image
                        // ToDo: send image
                    });
                }
            }
        }
    }
}
